# rag-kmk


[![image](https://img.shields.io/pypi/v/rag-kmk.svg)](https://pypi.python.org/pypi/rag-kmk)
[![image](https://img.shields.io/conda/vn/conda-forge/rag-kmk.svg)](https://anaconda.org/conda-forge/rag-kmk)


**A simple RAG implementation for educational purposes implemented by Murat Karakaya Akademi**


-   Free software: MIT License
-   Documentation: https://kmkarakaya.github.io/rag-kmk
    

## Features

-   TODO
